@@ -181,6 +181,28 @@ class FileGenerationJob(Job):
         return res
 
 
+class BulkFileGenerationJob(Job):
+    """
+    A single job (re)generating several endi.models.files.File
+    """
+    __tablename__ = 'bulk_file_generation_job'
+    __table_args__ = default_table_args
+    __mapper_args__ = {'polymorphic_identity': 'bulk_file_generation'}
+    id = Column(Integer, ForeignKey('job.id'), primary_key=True)
+    error_messages = Column(JsonEncodedList, default=[])
+    messages = Column(JsonEncodedList, default=None)
+    results_list = Column(JsonEncodedList, default=[])
+    label = "Génération de fichiers en lot"
+
+    def todict(self):
+        res = Job.todict(self)
+        res['results_list'] = self.results_list
+        res['error_messages'] = self.error_messages
+        res['messages'] = self.messages
+
+        return res
+
+
 class MailHistory(DBBASE):
     """
     Stores the history of mail sent by our application to any company
