@@ -133,7 +133,10 @@ def _clean_old_operations(old_ids):
 
 
 class KnownError(Exception):
-    pass
+    def __init__(self, *args, **kwargs):
+        Exception.__init__(*args, **kwargs)
+        if len(args) >= 1:
+            self.message = args[0]
 
 
 class AccountingDataParser(object):
